Scheme Link (link)

# Scheme Link (`link`)

## Scheme Link

class `orangecanvas.scheme.link.` `SchemeLink`(source_node, source_channel, sink_node, sink_channel, enabled=True, properties=None, parent=None)

  Bases: `PyQt5.QtCore.QObject`

  A instantiation of a link between two `SchemeNode` instances in a `Scheme`.

  Parameters: | source_node (`SchemeNode`) – Source node. source_channel (`OutputSignal`) – The source widget’s signal. sink_node (`SchemeNode`) – The sink node. sink_channel (`InputSignal`) – The sink widget’s input signal. properties (dict) – Additional link properties.

  `enabled_changed`(enabled)

    The link enabled state has changed

  `dynamic_enabled_changed`(enabled)

    The link dynamic enabled state has changed.

  `state_changed`

    Runtime link state has changed

  class `State`

    Bases: `enum.IntEnum`

    Flags indicating the runtime state of a link

    `NoState` = 0

      The link has no associated state.

    `Empty` = 1

      A link is empty when it has no value on it

    `Active` = 2

      A link is active when the source node provides a value on output

    `Pending` = 4

      A link is pending when it’s sink node has not yet been notified of a change (note that Empty|Pending is a valid state)

  `source_type`()

    Return the type of the source channel.

  `sink_type`()

    Return the type of the sink channel.

  `is_dynamic`()

    Is this link dynamic.

  `set_enabled`(enabled)

    Enable/disable the link.

  `enabled`

    Is this link enabled.

  `set_dynamic_enabled`(enabled)

    Enable/disable the dynamic link. Has no effect if the link is not dynamic.

  `dynamic_enabled`

    Is this a dynamic link and is dynamic_enabled set to True

  `set_runtime_state`(state)

    Set the link’s runtime state.

    Parameters: | state (SchemeLink.State) –

  `runtime_state`()

    Returns: | state
    Return type: | SchemeLink.State

  `set_tool_tip`(tool_tip)

    Set the link tool tip.

  `tool_tip`

    Link tool tip.